/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * Information about the connection monitor.
 *
 * @extends models['BaseResource']
 */
class ConnectionMonitorResult extends models['BaseResource'] {
  /**
   * Create a ConnectionMonitorResult.
   * @member {string} [name] Name of the connection monitor.
   * @member {string} [id] ID of the connection monitor.
   * @member {string} [etag] Default value: 'A unique read-only string that
   * changes whenever the resource is updated.' .
   * @member {string} [type] Connection monitor type.
   * @member {string} [location] Connection monitor location.
   * @member {object} [tags] Connection monitor tags.
   * @member {object} source
   * @member {string} [source.resourceId] The ID of the resource used as the
   * source by connection monitor.
   * @member {number} [source.port] The source port used by connection monitor.
   * @member {object} destination
   * @member {string} [destination.resourceId] The ID of the resource used as
   * the destination by connection monitor.
   * @member {string} [destination.address] Address of the connection monitor
   * destination (IP or domain name).
   * @member {number} [destination.port] The destination port used by
   * connection monitor.
   * @member {boolean} [autoStart] Determines if the connection monitor will
   * start automatically once created. Default value: true .
   * @member {number} [monitoringIntervalInSeconds] Monitoring interval in
   * seconds. Default value: 60 .
   * @member {string} [provisioningState] The provisioning state of the
   * connection monitor. Possible values include: 'Succeeded', 'Updating',
   * 'Deleting', 'Failed'
   * @member {date} [startTime] The date and time when the connection monitor
   * was started.
   * @member {string} [monitoringStatus] The monitoring status of the
   * connection monitor.
   */
  constructor() {
    super();
  }

  /**
   * Defines the metadata of ConnectionMonitorResult
   *
   * @returns {object} metadata of ConnectionMonitorResult
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'ConnectionMonitorResult',
      type: {
        name: 'Composite',
        className: 'ConnectionMonitorResult',
        modelProperties: {
          name: {
            required: false,
            readOnly: true,
            serializedName: 'name',
            type: {
              name: 'String'
            }
          },
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          etag: {
            required: false,
            serializedName: 'etag',
            defaultValue: 'A unique read-only string that changes whenever the resource is updated.',
            type: {
              name: 'String'
            }
          },
          type: {
            required: false,
            readOnly: true,
            serializedName: 'type',
            type: {
              name: 'String'
            }
          },
          location: {
            required: false,
            serializedName: 'location',
            type: {
              name: 'String'
            }
          },
          tags: {
            required: false,
            serializedName: 'tags',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          },
          source: {
            required: true,
            serializedName: 'properties.source',
            type: {
              name: 'Composite',
              className: 'ConnectionMonitorSource'
            }
          },
          destination: {
            required: true,
            serializedName: 'properties.destination',
            type: {
              name: 'Composite',
              className: 'ConnectionMonitorDestination'
            }
          },
          autoStart: {
            required: false,
            serializedName: 'properties.autoStart',
            defaultValue: true,
            type: {
              name: 'Boolean'
            }
          },
          monitoringIntervalInSeconds: {
            required: false,
            serializedName: 'properties.monitoringIntervalInSeconds',
            defaultValue: 60,
            type: {
              name: 'Number'
            }
          },
          provisioningState: {
            required: false,
            serializedName: 'properties.provisioningState',
            type: {
              name: 'String'
            }
          },
          startTime: {
            required: false,
            serializedName: 'properties.startTime',
            type: {
              name: 'DateTime'
            }
          },
          monitoringStatus: {
            required: false,
            serializedName: 'properties.monitoringStatus',
            type: {
              name: 'String'
            }
          }
        }
      }
    };
  }
}

module.exports = ConnectionMonitorResult;
